export default {
    "index": 1,
    "lineNumber": 1,
    "column": 2,
    "message": "Invalid regular expression: /(?<a)/: Invalid capture group name"
};